@@ -14,7 +14,7 @@ def configure_logging_to_standard_output(logging_level: int):
     verbose_formatter = logging.Formatter(
         '[%(asctime)s] %(levelname)s - %(name)s - %(message)s',
         '%Y-%m-%d %H:%M:%S')
-    is_info = logging_level == logging.INFO
+    is_info = logging_level == logging.WARNING
     is_debug = logging_level == logging.DEBUG
     formatter = verbose_formatter if is_info or is_debug else simple_formatter
     handler.setFormatter(formatter)
